## ClickHouse Connect

A suite of Python packages for connecting Python to ClickHouse:
* Pandas DataFrames
* Numpy Arrays
* PyArrow Tables
* SQLAlchemy 1.3 and 1.4 (limited feature set)
* Apache Superset 1.4+


### Complete Documentation
The documentation for ClickHouse Connect has moved to
[ClickHouse Docs](https://clickhouse.com/docs/en/integrations/language-clients/python/intro) 


### Installation

```
pip install clickhouse-connect
```

ClickHouse Connect requires Python 3.7 or higher.  
